Learn R Programming

ecochange (version 2.9.3.1)

getGADM: Get Geographic Adminitrative Unit

Description

This function is a wrapper of gadm that helps users to retrieve Geographic Administrative Data Maps (GADM).

Usage

getGADM(unit.nm = NULL, 
    level = 2, country = "COL", 
    path = tempdir())

Value

SpatialPolygonsDataFrame or character vector of GADM units..

Arguments

unit.nm

character or NULL. Name of Geographic Administrative Data Map (e.g., municipality), or the name of such an unit plus its corresponding higher-level unit (e.g., department/state). If NULL then a list of administrative subdivisions is printed.

level

numeric. A number between zero and two, indicating any of the levels of administrative subdivisions (0=country, 1=first administrative subdivision, and 2=second administrative subdivision).

country

character. ISO code specifying a country. Default 'COL'

path

character. Path name indicating where the unit will be stored. Default stores the data in a temporary directory.

Author

Wilson Lara Henao <wilarhen@gmail.com> [aut, cre], Victor Gutierrez-Velez [aut], Ivan Gonzalez [ctb], Maria C. Londono [ctb]

References

https://gadm.org/

Examples

Run this code
## Printing municipalities of Colombia:

     # \donttest{
         muni <- getGADM(NA)
         head(muni)
     # }

Run the code above in your browser using DataLab